/**
  ******************************************************************************
  * @file    stm32_it.c
  * @author  MCD Application Team
  * @version V4.0.0
  * @date    21-January-2013
  * @brief   Main Interrupt Service Routines.
  *          This file provides template for all exceptions handler and peripherals
  *          interrupt service routine.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT 2013 STMicroelectronics</center></h2>
  *
  * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
  * You may not use this file except in compliance with the License.
  * You may obtain a copy of the License at:
  *
  *        http://www.st.com/software_license_agreement_liberty_v2
  *
  * Unless required by applicable law or agreed to in writing, software 
  * distributed under the License is distributed on an "AS IS" BASIS, 
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
  ******************************************************************************
  */

#include "hw_config.h"
#include "stm32_it.h"
#include "usb_lib.h"
#include "usb_istr.h"

/******************************************************************************/
/*            Cortex-M Processor Exceptions Handlers                         */
/******************************************************************************/

/** Handles NMI exception. */
void NMI_Handler(void)
{
}

/** Handles Hard Fault exception. */
void HardFault_Handler(void)
{
	Buzzer_On();
  /* Go to infinite loop when Hard Fault exception occurs */
  while (1)
  {
  }
}

/** Handles Memory Manage exception. */
void MemManage_Handler(void)
{
	Buzzer_On();
  /* Go to infinite loop when Memory Manage exception occurs */
  while (1)
  {
  }
}

/** Handles Bus Fault exception. */
void BusFault_Handler(void)
{
	Buzzer_On();
  /* Go to infinite loop when Bus Fault exception occurs */
  while (1)
  {
  }
}

/** Handles Usage Fault exception. */
void UsageFault_Handler(void)
{
	Buzzer_On();
  /* Go to infinite loop when Usage Fault exception occurs */
  while (1)
  {
  }
}

/** Handles SVCall exception. */
void SVC_Handler(void)
{
}

/** Handles Debug Monitor exception. */
void DebugMon_Handler(void)
{
}

/** Handles PendSVC exception. */
void PendSV_Handler(void)
{
}

extern __IO uint32_t TimingDelay;
void SysTick_Handler(void)
{
	TimingDelay--;
}

/** This function handles USB Low Priority interrupts requests. */
#if defined(STM32L1XX_MD) || defined(STM32L1XX_HD)|| defined(STM32L1XX_MD_PLUS)|| defined (STM32F37X)
void USB_LP_IRQHandler(void)
#else
void USB_LP_CAN1_RX0_IRQHandler(void)
#endif
{
  USB_Istr();
}

/** This function handles USB WakeUp interrupt request. */
#if defined(STM32L1XX_MD) || defined(STM32L1XX_HD)|| defined(STM32L1XX_MD_PLUS)
void USB_FS_WKUP_IRQHandler(void)
#else
void USBWakeUp_IRQHandler(void)
#endif
{
  EXTI_ClearITPendingBit(EXTI_Line18);
}

/******************************************************************************/
/*                 STM32 Peripherals Interrupt Handlers                   */
/*  Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  */
/*  available peripheral interrupt handler's name please refer to the startup */
/*  file (startup_stm32xxx.s).                                            */
/******************************************************************************/

/** Handles PPP interrupt request. */
/*void PPP_IRQHandler(void)
{
}*/

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/

